"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.baseDsPackageValidator = exports.npmPackageValidator = exports.npmTokenValidator = exports.websocketValidator = exports.password = exports.jfrogUsernameValidator = exports.githubUsernameOrEmail = exports.atLeastOne = exports.dslSafeName = exports.safeName = void 0;
const reservedWords_1 = require("./reservedWords");
const safeNameRegex = /^([a-zA-Z0-9\-]+)$/;
const leadingNumberRegex = /^([0-9])/;
const githubUsernameRegex = /^([a-z\d]+-)*[a-z\d]+$/i;
const jfrogUsernameRegex = /^([a-zA-Z0-9\_\-\.\@]+)$/i;
const emailAddressRegex = /^([\w_\.\-\+])+\@([\w\-]+\.)+([\w]{2,10})+$/;
const passwordRegex = /((?=.*\d)|(?=.*\W+))(?![.\n])(?=.*[A-Z])(?=.*[a-z]).*$/;
const websocketRegex = /wss?:\/\/[-a-zA-Z0-9@:%._\+~#=]{1,256}\b([-a-zA-Z0-9()@:%_\+.~#?&\/=]*)\b\/*$/;
const npmTokenRegex = /^([a-zA-Z0-9\_]+)$/;
const npmPackageRegex = /^(@[a-z0-9-~][a-z0-9-._~]*\/)?[a-z0-9-~][a-z0-9-._~]*$/;
const safeName = (value) => safeNameRegex.test(value) || 'Name cannot have spaces or special characters other than dashes.';
exports.safeName = safeName;
const dslSafeName = (value) => {
    const words = value.split('-');
    const containsLeadingNumbers = words.some((word) => leadingNumberRegex.test(word));
    const containsReservedWords = words.some((word) => reservedWords_1.reservedJavaWords.includes(word.toLowerCase()));
    return ((safeNameRegex.test(value) && !containsLeadingNumbers && !containsReservedWords) ||
        `Name cannot have spaces, special characters (other than dashes), Java reserved words. Name cannot have numbers at the start or after dash.`);
};
exports.dslSafeName = dslSafeName;
const atLeastOne = (answers) => answers.length ? true : 'You must choose at least one.';
exports.atLeastOne = atLeastOne;
const githubUsernameOrEmail = (value) => githubUsernameRegex.test(value) ||
    emailAddressRegex.test(value) ||
    'Not a valid github username or email address.';
exports.githubUsernameOrEmail = githubUsernameOrEmail;
const jfrogUsernameValidator = (value) => jfrogUsernameRegex.test(value) || 'Not a valid jfrog username.';
exports.jfrogUsernameValidator = jfrogUsernameValidator;
const password = (value) => passwordRegex.test(value) ||
    'Passwords should contain at least 1 uppercase letter, 1 lowercase letter, and 1 number or special character.';
exports.password = password;
const websocketValidator = (value) => websocketRegex.test(value) || 'Not a valid websocket';
exports.websocketValidator = websocketValidator;
const npmTokenValidator = (value) => npmTokenRegex.test(value) || 'Not a valid .npmrc auth token';
exports.npmTokenValidator = npmTokenValidator;
const npmPackageValidator = (value) => npmPackageRegex.test(value) || 'Not a valid npm package';
exports.npmPackageValidator = npmPackageValidator;
const baseDsPackageValidator = (value) => npmPackageRegex.test(value) || 'Not a valid base design system package';
exports.baseDsPackageValidator = baseDsPackageValidator;
